@@ -1,16 +1,13 @@
 from typing import Dict, Optional
 from yaml import load, FullLoader
-import json
 
 from google.ads.googleads.client import GoogleAdsClient
-from google.oauth2.credentials import Credentials
 
 from arcane.datastore import Client as DatastoreClient
-from arcane.core import UserRightsEnum, RightsLevelEnum, BadRequestError, BaseAccount, GOOGLE_ADS_USER_CREDENTIAL_KIND
+from arcane.core import UserRightsEnum, RightsLevelEnum, BadRequestError, BaseAccount
 from arcane.requests import call_get_route
-from arcane.secret import decrypt
+from arcane.credentials import get_user_decrypted_credentials
 
-from .exceptions import EmptyCredentialsError
 
 def remove_dash(account_id: str) -> str:
     """ Removes '-' from account_id to make it valid for requests """
@@ -50,23 +47,6 @@ def get_google_ads_account(
     return accounts[0]
 
 
-def _get_google_ads_user_crendential(
-    user_email: str,
-    datastore_client: Optional[DatastoreClient] = None,
-    gcp_credentials_path: Optional[str] = None,
-    gcp_project: Optional[str] = None
-) -> Dict:
-    if not datastore_client:
-        datastore_client = _init_datastore_client(gcp_credentials_path, gcp_project)
-    query = datastore_client.query(kind=GOOGLE_ADS_USER_CREDENTIAL_KIND).add_filter('email', '=', user_email)
-    users_credential = list(query.fetch())
-    if len(users_credential) == 0:
-        raise BadRequestError(f'Error while getting google ads user credentials with mail: {user_email}. No entity corresponding.')
-    elif len(users_credential) > 1:
-        raise BadRequestError(f'Error while getting google ads user credentials with mail: {user_email}. Several entities corresponding: {users_credential}')
-    return users_credential[0]
-
-
 def get_login_customer_id_and_developer_token(mcc_credentials_path: str):
     ads_credentials_file = open(mcc_credentials_path)
     parsed_credentials_file = load(ads_credentials_file, Loader=FullLoader)
@@ -74,13 +54,6 @@ def get_login_customer_id_and_developer_token(mcc_credentials_path: str):
     return str(parsed_credentials_file["login_customer_id"]), parsed_credentials_file["developer_token"]
 
 
-def _init_datastore_client(gcp_credentials_path, gcp_project):
-    if not gcp_credentials_path and not gcp_project:
-            raise BadRequestError('gcp_credentials_path or gcp_project should not be None if datastore_client is not provided')
-    return DatastoreClient.from_service_account_json(
-            gcp_credentials_path, project=gcp_project)
-
-
 def _get_user_initialized_client(
     user_email: str,
     secret_key_file: str,
@@ -90,32 +63,24 @@ def _get_user_initialized_client(
     datastore_client: Optional[DatastoreClient] = None,
     login_customer_id: Optional[str] = None,
 ):
-    user_credentials = _get_google_ads_user_crendential(user_email, datastore_client, gcp_credentials_path, gcp_project)
 
-    if user_credentials.get('credentials') is None:
-        error_message = "Please renew the access you give us. To do so: \n \n" \
-            "1 - Please visit: https://myaccount.google.com/permissions \n" \
-            "2 - Search for AMS in 'Third-party apps with account access' list \n" \
-            "3 - Click on it and press on 'Remove Access' \n" \
-            "4 - Close this dialog and try again to add an account \n \n" \
-            "If the problem persists, please contact our support team."
-        raise EmptyCredentialsError(error_message)
-
-    credentials = init_google_ads_credentials(user_credentials['credentials'], secret_key_file)
+    credentials = get_user_decrypted_credentials(user_email, secret_key_file, gcp_credentials_path, gcp_project, datastore_client)
 
     if login_customer_id is None:
         return GoogleAdsClient(
             credentials,
-            developer_token
+            developer_token,
+            use_proto_plus=True
         )
     return GoogleAdsClient(
         credentials,
         developer_token,
-        login_customer_id=login_customer_id
+        login_customer_id=login_customer_id,
+        use_proto_plus=True
     )
 
-
-def init_google_ads_credentials(credentials_encrypt: bytes, secret_key_file: str,):
-    credentials = json.loads(decrypt(credentials_encrypt, secret_key_file).decode('utf-8'))
-    credentials['token'] = None
-    return Credentials(**credentials)
+def _init_datastore_client(gcp_credentials_path: str, gcp_project: str):
+    if not gcp_credentials_path and not gcp_project:
+            raise BadRequestError('gcp_credentials_path or gcp_project should not be None if datastore_client is not provided')
+    return DatastoreClient.from_service_account_json(
+            gcp_credentials_path, project=gcp_project)
